
# getDesignParms() retrieves the design parameters from a poped database, 
#   using their original naming in MDL. This only works for covariates, 
#   e.g. if number of patients per group is optimised with poped, this
#   cannot be retrieved with this function.
getDesignParms <- function(poped.db) {
	des_parms <- sfg(bpop  = rep(NA,nrow(poped.db$parameters$bpop)), a = poped.db$design$a)
	return(des_parms[!is.na(des_parms)])
}

# updatedDosing2simulx() takes a design object (the initial design) and a 
# 	vector of design parameters (the updated design) and returns the 
#   'treatment' simulx argument. Only bolus dosing is supported by this function. 
updatedDosing2simulx <- function(dsgnObj, parms) {
	interventionType <- unlist(lapply(dsgnObj@INTERVENTION, function(x) x[[1]]$type))
	bolus_parms <- which(interventionType == "bolus")
	adm <- vector(mode = "list", length = length(bolus_parms))
	for (i in bolus_parms) {
		interv_i <- dsgnObj@INTERVENTION[[i]][[1]]
		eval_in_parm <- function(x) eval(x, as.list(parms))
		adm[[i]] <- list(time = do.call(c, lapply(parse(text = interv_i$doseTime), eval_in_parm)),
				amount = do.call(c, lapply(parse(text = interv_i$amount), eval_in_parm)),
				target = interv_i$input)
	}
	adm
}

# parobj2simulx() processes a parameter object into a format suitable for simulx input,
#   i.e. structural and variability parameters together in a named vector.
parobj2simulx <- function(parObj) {
	STRUCTURAL <- sapply(parObj@STRUCTURAL,function(x)as.numeric(x[["value"]]))
	VARIABILITY <- sapply(parObj@VARIABILITY,function(x)as.numeric(x[["value"]]))
	c(STRUCTURAL, VARIABILITY)	
}
